@@ -438,6 +438,39 @@ class TestNLBGaussSeidel(unittest.TestCase):
 
         self.assertEqual(nlbgs._iter_count, 9, 'res_ref should make this take more iters.')
 
+    def test_guess_nonlinear(self):
+        class SmartGroup(om.Group):
+
+            def setup(self):
+                self.add_subsystem('c1', om.ExecComp('y = 2.7951 + 10.56*x**2 - 5.4*x**3 + 0.5*x**4'), promotes=['*'])
+                self.add_subsystem('c2', om.ExecComp('x = y/8.954'), promotes=['*'])
+
+                self.nonlinear_solver = om.NonlinearBlockGS()
+                self.nonlinear_solver.options['maxiter'] = 100
+                self.nonlinear_solver.options['atol'] = 1e-6
+
+            def guess_nonlinear(self, inputs, outputs, residuals):
+                x = outputs['x']
+                y = outputs['y']
+
+                if np.abs(x) > 1.0 or np.abs(y) > 10.0:
+                    # Pull out of divergence zone.
+                    x = outputs['x'] = 0.5
+                    outputs['y'] = 2.7951 + 10.56*x**2 - 5.4*x**3 + 0.5*x**4
+
+        prob = om.Problem(model=SmartGroup())
+
+        prob.setup()
+        prob.set_solver_print(level=0)
+
+        # This will mess things up. Only guess_nonlinear can save us.
+        prob['y'] = 1000.0
+        prob['x'] = 1000.0
+
+        prob.run_model()
+
+        assert_near_equal(prob['x'], 0.67883021, 1e-5)
+
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class ProcTestCase1(unittest.TestCase):
